package de.ecm4u.fcproclienttest;

import ifresco.fcpro.client.FCproClient;
import ifresco.fcpro.client.FCproJob;
import ifresco.fcpro.client.FCproSetting;
import ifresco.fcpro.client.FCproStatus;
import java.io.File;

public class Main {

    public static void main(String[] args) {
        FCproClient client = prepareClient();

        for (int i = 0; i < 10; i++) {
            FCproClientRunnable ct = new FCproClientRunnable(client);
            Thread t = new Thread(ct);
            t.setName("t" + i);
            t.start();
        }
    }

    private static FCproClient prepareClient() {
        FCproClient client = new FCproClient();
        client.setEndpoint("https://autoocr.may.co.at:8001/AutoOCRService");
        client.setUser("admin");
        client.setPassword("autoocr");
        client.setApiHash(25940);
        return client;
    }

    private static class FCproClientRunnable implements Runnable {

        private final FCproClient client;

        public FCproClientRunnable(FCproClient client) {
            this.client = client;
        }

        @Override
        public void run() {
            String name = Thread.currentThread().getName();

            log(name, "==== Server-Zustand ====");
            log(name, "getServerHash():\t" + client.getServerHash());
            log(name, "getServerVersion():\t" + client.getServerVersion());
            log(name, "getAvgSecPerPage():\t" + client.getAvgSecPerPage());
            log(name, "getNrOfDocumentsInQueue():\t" + client.getNrOfDocumentsInQueue());
            log(name, "getNrOfPagesInQueue():\t" + client.getNrOfPagesInQueue());
            log(name, "getAvailablePages():\t" + client.getAvailablePages());

            log(name, "==== getSettings ====");
            FCproSetting[] settings = client.getSettings();
            for (FCproSetting setting : settings) {
                log(name, setting.getSettingsName());
            }

            FCproJob upload = client.upload(new File("/tmp/example.pdf"), "application/pdf", "iOCR - German", name);
            log(name, upload.getGuid());
            long before = System.currentTimeMillis();
            FCproStatus completionStatus = client.waitForCompletion(upload.getGuid(), TIMEOUT, SLEEPTIME);
            log(name, (System.currentTimeMillis() - before) + "ms");
            log(name, completionStatus.toString());
        }

        private static final int TIMEOUT = 60_000;
        private static final int SLEEPTIME = 10_000;

        private void log(String name, String msg) {
            System.out.println("[" + name + "] " + msg);
        }
    }

}
